@@ -32,10 +32,17 @@ class PlotListView : public QListView
 	private slots:
 		//! コンテキストメニューを表示する
 		void showContextMenu(const QPoint &);
+#if QT_VERSION >= 0x040200
+		void setHandler(const QUrl &url);
+#endif
 
 	private:
 		// don't implement these
 		PlotListView(const PlotListView &);
 		PlotListView &operator=(const PlotListView &);
+
+#if QT_VERSION >= 0x040200
+		QString handler;
+#endif
 };
 #endif // PLOT_LIST_VIEW_INCLUDED
